# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class BounceProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sender': 'str',
        'created_at': 'datetime',
        'bounce_type': 'str',
        'bounce_mta': 'str',
        'subject': 'str',
        'id': 'str'
    }

    attribute_map = {
        'sender': 'sender',
        'created_at': 'createdAt',
        'bounce_type': 'bounceType',
        'bounce_mta': 'bounceMta',
        'subject': 'subject',
        'id': 'id'
    }

    def __init__(self, sender=None, created_at=None, bounce_type=None, bounce_mta=None, subject=None, id=None, local_vars_configuration=None):  # noqa: E501
        """BounceProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sender = None
        self._created_at = None
        self._bounce_type = None
        self._bounce_mta = None
        self._subject = None
        self._id = None
        self.discriminator = None

        self.sender = sender
        self.created_at = created_at
        self.bounce_type = bounce_type
        self.bounce_mta = bounce_mta
        self.subject = subject
        if id is not None:
            self.id = id

    @property
    def sender(self):
        """Gets the sender of this BounceProjection.  # noqa: E501


        :return: The sender of this BounceProjection.  # noqa: E501
        :rtype: str
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this BounceProjection.


        :param sender: The sender of this BounceProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sender is None:  # noqa: E501
            raise ValueError("Invalid value for `sender`, must not be `None`")  # noqa: E501

        self._sender = sender

    @property
    def created_at(self):
        """Gets the created_at of this BounceProjection.  # noqa: E501


        :return: The created_at of this BounceProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BounceProjection.


        :param created_at: The created_at of this BounceProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def bounce_type(self):
        """Gets the bounce_type of this BounceProjection.  # noqa: E501


        :return: The bounce_type of this BounceProjection.  # noqa: E501
        :rtype: str
        """
        return self._bounce_type

    @bounce_type.setter
    def bounce_type(self, bounce_type):
        """Sets the bounce_type of this BounceProjection.


        :param bounce_type: The bounce_type of this BounceProjection.  # noqa: E501
        :type: str
        """

        self._bounce_type = bounce_type

    @property
    def bounce_mta(self):
        """Gets the bounce_mta of this BounceProjection.  # noqa: E501


        :return: The bounce_mta of this BounceProjection.  # noqa: E501
        :rtype: str
        """
        return self._bounce_mta

    @bounce_mta.setter
    def bounce_mta(self, bounce_mta):
        """Sets the bounce_mta of this BounceProjection.


        :param bounce_mta: The bounce_mta of this BounceProjection.  # noqa: E501
        :type: str
        """

        self._bounce_mta = bounce_mta

    @property
    def subject(self):
        """Gets the subject of this BounceProjection.  # noqa: E501


        :return: The subject of this BounceProjection.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this BounceProjection.


        :param subject: The subject of this BounceProjection.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def id(self):
        """Gets the id of this BounceProjection.  # noqa: E501


        :return: The id of this BounceProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BounceProjection.


        :param id: The id of this BounceProjection.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BounceProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BounceProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class SendWithQueueResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'subject': 'str',
        'inbox_id': 'str',
        'header_id': 'str',
        'delivered': 'bool',
        'exception_name': 'str',
        'message': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'subject': 'subject',
        'inbox_id': 'inboxId',
        'header_id': 'headerId',
        'delivered': 'delivered',
        'exception_name': 'exceptionName',
        'message': 'message',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, user_id=None, subject=None, inbox_id=None, header_id=None, delivered=None, exception_name=None, message=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """SendWithQueueResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._subject = None
        self._inbox_id = None
        self._header_id = None
        self._delivered = None
        self._exception_name = None
        self._message = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        if subject is not None:
            self.subject = subject
        if inbox_id is not None:
            self.inbox_id = inbox_id
        self.header_id = header_id
        self.delivered = delivered
        if exception_name is not None:
            self.exception_name = exception_name
        if message is not None:
            self.message = message
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this SendWithQueueResult.  # noqa: E501


        :return: The id of this SendWithQueueResult.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SendWithQueueResult.


        :param id: The id of this SendWithQueueResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this SendWithQueueResult.  # noqa: E501


        :return: The user_id of this SendWithQueueResult.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this SendWithQueueResult.


        :param user_id: The user_id of this SendWithQueueResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def subject(self):
        """Gets the subject of this SendWithQueueResult.  # noqa: E501


        :return: The subject of this SendWithQueueResult.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this SendWithQueueResult.


        :param subject: The subject of this SendWithQueueResult.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def inbox_id(self):
        """Gets the inbox_id of this SendWithQueueResult.  # noqa: E501


        :return: The inbox_id of this SendWithQueueResult.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this SendWithQueueResult.


        :param inbox_id: The inbox_id of this SendWithQueueResult.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def header_id(self):
        """Gets the header_id of this SendWithQueueResult.  # noqa: E501


        :return: The header_id of this SendWithQueueResult.  # noqa: E501
        :rtype: str
        """
        return self._header_id

    @header_id.setter
    def header_id(self, header_id):
        """Sets the header_id of this SendWithQueueResult.


        :param header_id: The header_id of this SendWithQueueResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and header_id is None:  # noqa: E501
            raise ValueError("Invalid value for `header_id`, must not be `None`")  # noqa: E501

        self._header_id = header_id

    @property
    def delivered(self):
        """Gets the delivered of this SendWithQueueResult.  # noqa: E501


        :return: The delivered of this SendWithQueueResult.  # noqa: E501
        :rtype: bool
        """
        return self._delivered

    @delivered.setter
    def delivered(self, delivered):
        """Sets the delivered of this SendWithQueueResult.


        :param delivered: The delivered of this SendWithQueueResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and delivered is None:  # noqa: E501
            raise ValueError("Invalid value for `delivered`, must not be `None`")  # noqa: E501

        self._delivered = delivered

    @property
    def exception_name(self):
        """Gets the exception_name of this SendWithQueueResult.  # noqa: E501


        :return: The exception_name of this SendWithQueueResult.  # noqa: E501
        :rtype: str
        """
        return self._exception_name

    @exception_name.setter
    def exception_name(self, exception_name):
        """Sets the exception_name of this SendWithQueueResult.


        :param exception_name: The exception_name of this SendWithQueueResult.  # noqa: E501
        :type: str
        """

        self._exception_name = exception_name

    @property
    def message(self):
        """Gets the message of this SendWithQueueResult.  # noqa: E501


        :return: The message of this SendWithQueueResult.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this SendWithQueueResult.


        :param message: The message of this SendWithQueueResult.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def created_at(self):
        """Gets the created_at of this SendWithQueueResult.  # noqa: E501


        :return: The created_at of this SendWithQueueResult.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SendWithQueueResult.


        :param created_at: The created_at of this SendWithQueueResult.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this SendWithQueueResult.  # noqa: E501


        :return: The updated_at of this SendWithQueueResult.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SendWithQueueResult.


        :param updated_at: The updated_at of this SendWithQueueResult.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendWithQueueResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SendWithQueueResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.inbox_ruleset_controller_api import InboxRulesetControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestInboxRulesetControllerApi(unittest.TestCase):
    """InboxRulesetControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.inbox_ruleset_controller_api.InboxRulesetControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_new_inbox_ruleset(self):
        """Test case for create_new_inbox_ruleset

        Create an inbox ruleset  # noqa: E501
        """
        pass

    def test_delete_inbox_ruleset(self):
        """Test case for delete_inbox_ruleset

        Delete an inbox ruleset  # noqa: E501
        """
        pass

    def test_delete_inbox_rulesets(self):
        """Test case for delete_inbox_rulesets

        Delete inbox rulesets  # noqa: E501
        """
        pass

    def test_get_inbox_ruleset(self):
        """Test case for get_inbox_ruleset

        Get an inbox ruleset  # noqa: E501
        """
        pass

    def test_get_inbox_rulesets(self):
        """Test case for get_inbox_rulesets

        List inbox rulesets  # noqa: E501
        """
        pass

    def test_test_inbox_ruleset(self):
        """Test case for test_inbox_ruleset

        Test an inbox ruleset  # noqa: E501
        """
        pass

    def test_test_inbox_ruleset_receiving(self):
        """Test case for test_inbox_ruleset_receiving

        Test receiving with inbox rulesets  # noqa: E501
        """
        pass

    def test_test_inbox_ruleset_sending(self):
        """Test case for test_inbox_ruleset_sending

        Test sending with inbox rulesets  # noqa: E501
        """
        pass

    def test_test_inbox_rulesets_for_inbox(self):
        """Test case for test_inbox_rulesets_for_inbox

        Test inbox rulesets for inbox  # noqa: E501
        """
        pass

    def test_test_new_inbox_ruleset(self):
        """Test case for test_new_inbox_ruleset

        Test new inbox ruleset  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class StructuredOutputSchema(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'any_of': 'list[StructuredOutputSchema]',
        'default': 'object',
        'description': 'str',
        'enum': 'list[str]',
        'example': 'object',
        'format': 'str',
        'items': 'StructuredOutputSchema',
        'max_items': 'int',
        'min_items': 'int',
        'max_length': 'int',
        'min_length': 'int',
        'pattern': 'str',
        'properties': 'dict(str, StructuredOutputSchema)',
        'property_ordering': 'list[str]',
        'required': 'list[str]',
        'max_properties': 'int',
        'min_properties': 'int',
        'maximum': 'float',
        'minimum': 'float',
        'nullable': 'bool',
        'title': 'str',
        'type': 'str'
    }

    attribute_map = {
        'any_of': 'anyOf',
        'default': 'default',
        'description': 'description',
        'enum': 'enum',
        'example': 'example',
        'format': 'format',
        'items': 'items',
        'max_items': 'maxItems',
        'min_items': 'minItems',
        'max_length': 'maxLength',
        'min_length': 'minLength',
        'pattern': 'pattern',
        'properties': 'properties',
        'property_ordering': 'propertyOrdering',
        'required': 'required',
        'max_properties': 'maxProperties',
        'min_properties': 'minProperties',
        'maximum': 'maximum',
        'minimum': 'minimum',
        'nullable': 'nullable',
        'title': 'title',
        'type': 'type'
    }

    def __init__(self, any_of=None, default=None, description=None, enum=None, example=None, format=None, items=None, max_items=None, min_items=None, max_length=None, min_length=None, pattern=None, properties=None, property_ordering=None, required=None, max_properties=None, min_properties=None, maximum=None, minimum=None, nullable=None, title=None, type=None, local_vars_configuration=None):  # noqa: E501
        """StructuredOutputSchema - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._any_of = None
        self._default = None
        self._description = None
        self._enum = None
        self._example = None
        self._format = None
        self._items = None
        self._max_items = None
        self._min_items = None
        self._max_length = None
        self._min_length = None
        self._pattern = None
        self._properties = None
        self._property_ordering = None
        self._required = None
        self._max_properties = None
        self._min_properties = None
        self._maximum = None
        self._minimum = None
        self._nullable = None
        self._title = None
        self._type = None
        self.discriminator = None

        self.any_of = any_of
        self.default = default
        self.description = description
        self.enum = enum
        self.example = example
        self.format = format
        if items is not None:
            self.items = items
        self.max_items = max_items
        self.min_items = min_items
        self.max_length = max_length
        self.min_length = min_length
        self.pattern = pattern
        self.properties = properties
        self.property_ordering = property_ordering
        self.required = required
        self.max_properties = max_properties
        self.min_properties = min_properties
        self.maximum = maximum
        self.minimum = minimum
        self.nullable = nullable
        self.title = title
        self.type = type

    @property
    def any_of(self):
        """Gets the any_of of this StructuredOutputSchema.  # noqa: E501


        :return: The any_of of this StructuredOutputSchema.  # noqa: E501
        :rtype: list[StructuredOutputSchema]
        """
        return self._any_of

    @any_of.setter
    def any_of(self, any_of):
        """Sets the any_of of this StructuredOutputSchema.


        :param any_of: The any_of of this StructuredOutputSchema.  # noqa: E501
        :type: list[StructuredOutputSchema]
        """

        self._any_of = any_of

    @property
    def default(self):
        """Gets the default of this StructuredOutputSchema.  # noqa: E501


        :return: The default of this StructuredOutputSchema.  # noqa: E501
        :rtype: object
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this StructuredOutputSchema.


        :param default: The default of this StructuredOutputSchema.  # noqa: E501
        :type: object
        """

        self._default = default

    @property
    def description(self):
        """Gets the description of this StructuredOutputSchema.  # noqa: E501

        Provide a description of the schema to help the AI understand the schema.  # noqa: E501

        :return: The description of this StructuredOutputSchema.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this StructuredOutputSchema.

        Provide a description of the schema to help the AI understand the schema.  # noqa: E501

        :param description: The description of this StructuredOutputSchema.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def enum(self):
        """Gets the enum of this StructuredOutputSchema.  # noqa: E501

        When using type string and format enum pass a collection of enum values here.  # noqa: E501

        :return: The enum of this StructuredOutputSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._enum

    @enum.setter
    def enum(self, enum):
        """Sets the enum of this StructuredOutputSchema.

        When using type string and format enum pass a collection of enum values here.  # noqa: E501

        :param enum: The enum of this StructuredOutputSchema.  # noqa: E501
        :type: list[str]
        """

        self._enum = enum

    @property
    def example(self):
        """Gets the example of this StructuredOutputSchema.  # noqa: E501


        :return: The example of this StructuredOutputSchema.  # noqa: E501
        :rtype: object
        """
        return self._example

    @example.setter
    def example(self, example):
        """Sets the example of this StructuredOutputSchema.


        :param example: The example of this StructuredOutputSchema.  # noqa: E501
        :type: object
        """

        self._example = example

    @property
    def format(self):
        """Gets the format of this StructuredOutputSchema.  # noqa: E501

        Format for string types. Can be null, date-time or enum.  # noqa: E501

        :return: The format of this StructuredOutputSchema.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this StructuredOutputSchema.

        Format for string types. Can be null, date-time or enum.  # noqa: E501

        :param format: The format of this StructuredOutputSchema.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def items(self):
        """Gets the items of this StructuredOutputSchema.  # noqa: E501


        :return: The items of this StructuredOutputSchema.  # noqa: E501
        :rtype: StructuredOutputSchema
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this StructuredOutputSchema.


        :param items: The items of this StructuredOutputSchema.  # noqa: E501
        :type: StructuredOutputSchema
        """

        self._items = items

    @property
    def max_items(self):
        """Gets the max_items of this StructuredOutputSchema.  # noqa: E501


        :return: The max_items of this StructuredOutputSchema.  # noqa: E501
        :rtype: int
        """
        return self._max_items

    @max_items.setter
    def max_items(self, max_items):
        """Sets the max_items of this StructuredOutputSchema.


        :param max_items: The max_items of this StructuredOutputSchema.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_items is not None and max_items < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_items`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_items = max_items

    @property
    def min_items(self):
        """Gets the min_items of this StructuredOutputSchema.  # noqa: E501


        :return: The min_items of this StructuredOutputSchema.  # noqa: E501
        :rtype: int
        """
        return self._min_items

    @min_items.setter
    def min_items(self, min_items):
        """Sets the min_items of this StructuredOutputSchema.


        :param min_items: The min_items of this StructuredOutputSchema.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                min_items is not None and min_items < 0):  # noqa: E501
            raise ValueError("Invalid value for `min_items`, must be a value greater than or equal to `0`")  # noqa: E501

        self._min_items = min_items

    @property
    def max_length(self):
        """Gets the max_length of this StructuredOutputSchema.  # noqa: E501


        :return: The max_length of this StructuredOutputSchema.  # noqa: E501
        :rtype: int
        """
        return self._max_length

    @max_length.setter
    def max_length(self, max_length):
        """Sets the max_length of this StructuredOutputSchema.


        :param max_length: The max_length of this StructuredOutputSchema.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_length is not None and max_length < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_length`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_length = max_length

    @property
    def min_length(self):
        """Gets the min_length of this StructuredOutputSchema.  # noqa: E501


        :return: The min_length of this StructuredOutputSchema.  # noqa: E501
        :rtype: int
        """
        return self._min_length

    @min_length.setter
    def min_length(self, min_length):
        """Sets the min_length of this StructuredOutputSchema.


        :param min_length: The min_length of this StructuredOutputSchema.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                min_length is not None and min_length < 0):  # noqa: E501
            raise ValueError("Invalid value for `min_length`, must be a value greater than or equal to `0`")  # noqa: E501

        self._min_length = min_length

    @property
    def pattern(self):
        """Gets the pattern of this StructuredOutputSchema.  # noqa: E501


        :return: The pattern of this StructuredOutputSchema.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this StructuredOutputSchema.


        :param pattern: The pattern of this StructuredOutputSchema.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    @property
    def properties(self):
        """Gets the properties of this StructuredOutputSchema.  # noqa: E501

        Properties of an OBJECT schema. These are key value pairs where the key is the property name and the value is the schema for that property.  # noqa: E501

        :return: The properties of this StructuredOutputSchema.  # noqa: E501
        :rtype: dict(str, StructuredOutputSchema)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this StructuredOutputSchema.

        Properties of an OBJECT schema. These are key value pairs where the key is the property name and the value is the schema for that property.  # noqa: E501

        :param properties: The properties of this StructuredOutputSchema.  # noqa: E501
        :type: dict(str, StructuredOutputSchema)
        """

        self._properties = properties

    @property
    def property_ordering(self):
        """Gets the property_ordering of this StructuredOutputSchema.  # noqa: E501

        Pass an array of property names to specify the order of properties in the generated JSON object if required.  # noqa: E501

        :return: The property_ordering of this StructuredOutputSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._property_ordering

    @property_ordering.setter
    def property_ordering(self, property_ordering):
        """Sets the property_ordering of this StructuredOutputSchema.

        Pass an array of property names to specify the order of properties in the generated JSON object if required.  # noqa: E501

        :param property_ordering: The property_ordering of this StructuredOutputSchema.  # noqa: E501
        :type: list[str]
        """

        self._property_ordering = property_ordering

    @property
    def required(self):
        """Gets the required of this StructuredOutputSchema.  # noqa: E501


        :return: The required of this StructuredOutputSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this StructuredOutputSchema.


        :param required: The required of this StructuredOutputSchema.  # noqa: E501
        :type: list[str]
        """

        self._required = required

    @property
    def max_properties(self):
        """Gets the max_properties of this StructuredOutputSchema.  # noqa: E501


        :return: The max_properties of this StructuredOutputSchema.  # noqa: E501
        :rtype: int
        """
        return self._max_properties

    @max_properties.setter
    def max_properties(self, max_properties):
        """Sets the max_properties of this StructuredOutputSchema.


        :param max_properties: The max_properties of this StructuredOutputSchema.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_properties is not None and max_properties < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_properties`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_properties = max_properties

    @property
    def min_properties(self):
        """Gets the min_properties of this StructuredOutputSchema.  # noqa: E501


        :return: The min_properties of this StructuredOutputSchema.  # noqa: E501
        :rtype: int
        """
        return self._min_properties

    @min_properties.setter
    def min_properties(self, min_properties):
        """Sets the min_properties of this StructuredOutputSchema.


        :param min_properties: The min_properties of this StructuredOutputSchema.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                min_properties is not None and min_properties < 0):  # noqa: E501
            raise ValueError("Invalid value for `min_properties`, must be a value greater than or equal to `0`")  # noqa: E501

        self._min_properties = min_properties

    @property
    def maximum(self):
        """Gets the maximum of this StructuredOutputSchema.  # noqa: E501


        :return: The maximum of this StructuredOutputSchema.  # noqa: E501
        :rtype: float
        """
        return self._maximum

    @maximum.setter
    def maximum(self, maximum):
        """Sets the maximum of this StructuredOutputSchema.


        :param maximum: The maximum of this StructuredOutputSchema.  # noqa: E501
        :type: float
        """

        self._maximum = maximum

    @property
    def minimum(self):
        """Gets the minimum of this StructuredOutputSchema.  # noqa: E501


        :return: The minimum of this StructuredOutputSchema.  # noqa: E501
        :rtype: float
        """
        return self._minimum

    @minimum.setter
    def minimum(self, minimum):
        """Sets the minimum of this StructuredOutputSchema.


        :param minimum: The minimum of this StructuredOutputSchema.  # noqa: E501
        :type: float
        """

        self._minimum = minimum

    @property
    def nullable(self):
        """Gets the nullable of this StructuredOutputSchema.  # noqa: E501


        :return: The nullable of this StructuredOutputSchema.  # noqa: E501
        :rtype: bool
        """
        return self._nullable

    @nullable.setter
    def nullable(self, nullable):
        """Sets the nullable of this StructuredOutputSchema.


        :param nullable: The nullable of this StructuredOutputSchema.  # noqa: E501
        :type: bool
        """

        self._nullable = nullable

    @property
    def title(self):
        """Gets the title of this StructuredOutputSchema.  # noqa: E501


        :return: The title of this StructuredOutputSchema.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this StructuredOutputSchema.


        :param title: The title of this StructuredOutputSchema.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def type(self):
        """Gets the type of this StructuredOutputSchema.  # noqa: E501

        Primitive JSON schema types with a fallback CUSTOM for unknown values.  # noqa: E501

        :return: The type of this StructuredOutputSchema.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this StructuredOutputSchema.

        Primitive JSON schema types with a fallback CUSTOM for unknown values.  # noqa: E501

        :param type: The type of this StructuredOutputSchema.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"string", "number", "integer", "boolean", "object", "array", "null"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StructuredOutputSchema):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StructuredOutputSchema):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class WebhookDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'basic_auth': 'bool',
        'name': 'str',
        'phone_id': 'str',
        'inbox_id': 'str',
        'request_body_template': 'str',
        'url': 'str',
        'method': 'str',
        'payload_json_schema': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'event_name': 'str',
        'request_headers': 'WebhookHeaders',
        'ignore_insecure_ssl_certificates': 'bool',
        'use_static_ip_range': 'bool',
        'health_status': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'basic_auth': 'basicAuth',
        'name': 'name',
        'phone_id': 'phoneId',
        'inbox_id': 'inboxId',
        'request_body_template': 'requestBodyTemplate',
        'url': 'url',
        'method': 'method',
        'payload_json_schema': 'payloadJsonSchema',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'event_name': 'eventName',
        'request_headers': 'requestHeaders',
        'ignore_insecure_ssl_certificates': 'ignoreInsecureSslCertificates',
        'use_static_ip_range': 'useStaticIpRange',
        'health_status': 'healthStatus'
    }

    def __init__(self, id=None, user_id=None, basic_auth=None, name=None, phone_id=None, inbox_id=None, request_body_template=None, url=None, method=None, payload_json_schema=None, created_at=None, updated_at=None, event_name=None, request_headers=None, ignore_insecure_ssl_certificates=None, use_static_ip_range=None, health_status=None, local_vars_configuration=None):  # noqa: E501
        """WebhookDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._basic_auth = None
        self._name = None
        self._phone_id = None
        self._inbox_id = None
        self._request_body_template = None
        self._url = None
        self._method = None
        self._payload_json_schema = None
        self._created_at = None
        self._updated_at = None
        self._event_name = None
        self._request_headers = None
        self._ignore_insecure_ssl_certificates = None
        self._use_static_ip_range = None
        self._health_status = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.basic_auth = basic_auth
        self.name = name
        self.phone_id = phone_id
        self.inbox_id = inbox_id
        self.request_body_template = request_body_template
        self.url = url
        self.method = method
        self.payload_json_schema = payload_json_schema
        self.created_at = created_at
        self.updated_at = updated_at
        self.event_name = event_name
        if request_headers is not None:
            self.request_headers = request_headers
        self.ignore_insecure_ssl_certificates = ignore_insecure_ssl_certificates
        self.use_static_ip_range = use_static_ip_range
        self.health_status = health_status

    @property
    def id(self):
        """Gets the id of this WebhookDto.  # noqa: E501

        ID of the Webhook  # noqa: E501

        :return: The id of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookDto.

        ID of the Webhook  # noqa: E501

        :param id: The id of this WebhookDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this WebhookDto.  # noqa: E501

        User ID of the Webhook  # noqa: E501

        :return: The user_id of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this WebhookDto.

        User ID of the Webhook  # noqa: E501

        :param user_id: The user_id of this WebhookDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def basic_auth(self):
        """Gets the basic_auth of this WebhookDto.  # noqa: E501

        Does webhook expect basic authentication? If true it means you created this webhook with a username and password. MailSlurp will use these in the URL to authenticate itself.  # noqa: E501

        :return: The basic_auth of this WebhookDto.  # noqa: E501
        :rtype: bool
        """
        return self._basic_auth

    @basic_auth.setter
    def basic_auth(self, basic_auth):
        """Sets the basic_auth of this WebhookDto.

        Does webhook expect basic authentication? If true it means you created this webhook with a username and password. MailSlurp will use these in the URL to authenticate itself.  # noqa: E501

        :param basic_auth: The basic_auth of this WebhookDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and basic_auth is None:  # noqa: E501
            raise ValueError("Invalid value for `basic_auth`, must not be `None`")  # noqa: E501

        self._basic_auth = basic_auth

    @property
    def name(self):
        """Gets the name of this WebhookDto.  # noqa: E501

        Name of the webhook  # noqa: E501

        :return: The name of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WebhookDto.

        Name of the webhook  # noqa: E501

        :param name: The name of this WebhookDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def phone_id(self):
        """Gets the phone_id of this WebhookDto.  # noqa: E501

        The phoneNumberId that the Webhook will be triggered by. If null then webhook triggered at account level or inbox level if inboxId set  # noqa: E501

        :return: The phone_id of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_id

    @phone_id.setter
    def phone_id(self, phone_id):
        """Sets the phone_id of this WebhookDto.

        The phoneNumberId that the Webhook will be triggered by. If null then webhook triggered at account level or inbox level if inboxId set  # noqa: E501

        :param phone_id: The phone_id of this WebhookDto.  # noqa: E501
        :type: str
        """

        self._phone_id = phone_id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this WebhookDto.  # noqa: E501

        The inbox that the Webhook will be triggered by. If null then webhook triggered at account level or phone level if phoneId set  # noqa: E501

        :return: The inbox_id of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this WebhookDto.

        The inbox that the Webhook will be triggered by. If null then webhook triggered at account level or phone level if phoneId set  # noqa: E501

        :param inbox_id: The inbox_id of this WebhookDto.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def request_body_template(self):
        """Gets the request_body_template of this WebhookDto.  # noqa: E501

        Request body template for HTTP request that will be sent for the webhook. Use Moustache style template variables to insert values from the original event payload.  # noqa: E501

        :return: The request_body_template of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._request_body_template

    @request_body_template.setter
    def request_body_template(self, request_body_template):
        """Sets the request_body_template of this WebhookDto.

        Request body template for HTTP request that will be sent for the webhook. Use Moustache style template variables to insert values from the original event payload.  # noqa: E501

        :param request_body_template: The request_body_template of this WebhookDto.  # noqa: E501
        :type: str
        """

        self._request_body_template = request_body_template

    @property
    def url(self):
        """Gets the url of this WebhookDto.  # noqa: E501

        URL of your server that the webhook will be sent to. The schema of the JSON that is sent is described by the payloadJsonSchema.  # noqa: E501

        :return: The url of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this WebhookDto.

        URL of your server that the webhook will be sent to. The schema of the JSON that is sent is described by the payloadJsonSchema.  # noqa: E501

        :param url: The url of this WebhookDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def method(self):
        """Gets the method of this WebhookDto.  # noqa: E501

        HTTP method that your server endpoint must listen for  # noqa: E501

        :return: The method of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this WebhookDto.

        HTTP method that your server endpoint must listen for  # noqa: E501

        :param method: The method of this WebhookDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and method is None:  # noqa: E501
            raise ValueError("Invalid value for `method`, must not be `None`")  # noqa: E501
        allowed_values = ["POST", "DELETE", "GET", "PUT", "PATCH", "HEAD", "OPTIONS", "TRACE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def payload_json_schema(self):
        """Gets the payload_json_schema of this WebhookDto.  # noqa: E501

        Deprecated. Fetch JSON Schema for webhook using the getJsonSchemaForWebhookPayload method  # noqa: E501

        :return: The payload_json_schema of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._payload_json_schema

    @payload_json_schema.setter
    def payload_json_schema(self, payload_json_schema):
        """Sets the payload_json_schema of this WebhookDto.

        Deprecated. Fetch JSON Schema for webhook using the getJsonSchemaForWebhookPayload method  # noqa: E501

        :param payload_json_schema: The payload_json_schema of this WebhookDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and payload_json_schema is None:  # noqa: E501
            raise ValueError("Invalid value for `payload_json_schema`, must not be `None`")  # noqa: E501

        self._payload_json_schema = payload_json_schema

    @property
    def created_at(self):
        """Gets the created_at of this WebhookDto.  # noqa: E501

        When the webhook was created  # noqa: E501

        :return: The created_at of this WebhookDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this WebhookDto.

        When the webhook was created  # noqa: E501

        :param created_at: The created_at of this WebhookDto.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this WebhookDto.  # noqa: E501


        :return: The updated_at of this WebhookDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this WebhookDto.


        :param updated_at: The updated_at of this WebhookDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def event_name(self):
        """Gets the event_name of this WebhookDto.  # noqa: E501

        Webhook trigger event name  # noqa: E501

        :return: The event_name of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this WebhookDto.

        Webhook trigger event name  # noqa: E501

        :param event_name: The event_name of this WebhookDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"EMAIL_RECEIVED", "NEW_EMAIL", "NEW_CONTACT", "NEW_ATTACHMENT", "EMAIL_OPENED", "EMAIL_READ", "DELIVERY_STATUS", "BOUNCE", "BOUNCE_RECIPIENT", "NEW_SMS", "NEW_GUEST_USER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_name not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_name` ({0}), must be one of {1}"  # noqa: E501
                .format(event_name, allowed_values)
            )

        self._event_name = event_name

    @property
    def request_headers(self):
        """Gets the request_headers of this WebhookDto.  # noqa: E501


        :return: The request_headers of this WebhookDto.  # noqa: E501
        :rtype: WebhookHeaders
        """
        return self._request_headers

    @request_headers.setter
    def request_headers(self, request_headers):
        """Sets the request_headers of this WebhookDto.


        :param request_headers: The request_headers of this WebhookDto.  # noqa: E501
        :type: WebhookHeaders
        """

        self._request_headers = request_headers

    @property
    def ignore_insecure_ssl_certificates(self):
        """Gets the ignore_insecure_ssl_certificates of this WebhookDto.  # noqa: E501

        Should notifier ignore insecure SSL certificates  # noqa: E501

        :return: The ignore_insecure_ssl_certificates of this WebhookDto.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_insecure_ssl_certificates

    @ignore_insecure_ssl_certificates.setter
    def ignore_insecure_ssl_certificates(self, ignore_insecure_ssl_certificates):
        """Sets the ignore_insecure_ssl_certificates of this WebhookDto.

        Should notifier ignore insecure SSL certificates  # noqa: E501

        :param ignore_insecure_ssl_certificates: The ignore_insecure_ssl_certificates of this WebhookDto.  # noqa: E501
        :type: bool
        """

        self._ignore_insecure_ssl_certificates = ignore_insecure_ssl_certificates

    @property
    def use_static_ip_range(self):
        """Gets the use_static_ip_range of this WebhookDto.  # noqa: E501

        Should notifier use static IP range when sending webhook payload  # noqa: E501

        :return: The use_static_ip_range of this WebhookDto.  # noqa: E501
        :rtype: bool
        """
        return self._use_static_ip_range

    @use_static_ip_range.setter
    def use_static_ip_range(self, use_static_ip_range):
        """Sets the use_static_ip_range of this WebhookDto.

        Should notifier use static IP range when sending webhook payload  # noqa: E501

        :param use_static_ip_range: The use_static_ip_range of this WebhookDto.  # noqa: E501
        :type: bool
        """

        self._use_static_ip_range = use_static_ip_range

    @property
    def health_status(self):
        """Gets the health_status of this WebhookDto.  # noqa: E501

        Webhook health  # noqa: E501

        :return: The health_status of this WebhookDto.  # noqa: E501
        :rtype: str
        """
        return self._health_status

    @health_status.setter
    def health_status(self, health_status):
        """Sets the health_status of this WebhookDto.

        Webhook health  # noqa: E501

        :param health_status: The health_status of this WebhookDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"HEALTHY", "UNHEALTHY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and health_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `health_status` ({0}), must be one of {1}"  # noqa: E501
                .format(health_status, allowed_values)
            )

        self._health_status = health_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ProviderSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'mail_provider': 'str',
        'imap_host': 'str',
        'imap_port': 'int',
        'imap_ssl': 'bool',
        'imap_start_tls': 'bool',
        'smtp_host': 'str',
        'smtp_port': 'int',
        'smtp_ssl': 'bool',
        'smtp_start_tls': 'bool'
    }

    attribute_map = {
        'mail_provider': 'mailProvider',
        'imap_host': 'imapHost',
        'imap_port': 'imapPort',
        'imap_ssl': 'imapSsl',
        'imap_start_tls': 'imapStartTls',
        'smtp_host': 'smtpHost',
        'smtp_port': 'smtpPort',
        'smtp_ssl': 'smtpSsl',
        'smtp_start_tls': 'smtpStartTls'
    }

    def __init__(self, mail_provider=None, imap_host=None, imap_port=None, imap_ssl=None, imap_start_tls=None, smtp_host=None, smtp_port=None, smtp_ssl=None, smtp_start_tls=None, local_vars_configuration=None):  # noqa: E501
        """ProviderSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._mail_provider = None
        self._imap_host = None
        self._imap_port = None
        self._imap_ssl = None
        self._imap_start_tls = None
        self._smtp_host = None
        self._smtp_port = None
        self._smtp_ssl = None
        self._smtp_start_tls = None
        self.discriminator = None

        self.mail_provider = mail_provider
        self.imap_host = imap_host
        self.imap_port = imap_port
        self.imap_ssl = imap_ssl
        if imap_start_tls is not None:
            self.imap_start_tls = imap_start_tls
        self.smtp_host = smtp_host
        self.smtp_port = smtp_port
        self.smtp_ssl = smtp_ssl
        if smtp_start_tls is not None:
            self.smtp_start_tls = smtp_start_tls

    @property
    def mail_provider(self):
        """Gets the mail_provider of this ProviderSettings.  # noqa: E501


        :return: The mail_provider of this ProviderSettings.  # noqa: E501
        :rtype: str
        """
        return self._mail_provider

    @mail_provider.setter
    def mail_provider(self, mail_provider):
        """Sets the mail_provider of this ProviderSettings.


        :param mail_provider: The mail_provider of this ProviderSettings.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and mail_provider is None:  # noqa: E501
            raise ValueError("Invalid value for `mail_provider`, must not be `None`")  # noqa: E501
        allowed_values = ["GOOGLE", "MICROSOFT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and mail_provider not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `mail_provider` ({0}), must be one of {1}"  # noqa: E501
                .format(mail_provider, allowed_values)
            )

        self._mail_provider = mail_provider

    @property
    def imap_host(self):
        """Gets the imap_host of this ProviderSettings.  # noqa: E501


        :return: The imap_host of this ProviderSettings.  # noqa: E501
        :rtype: str
        """
        return self._imap_host

    @imap_host.setter
    def imap_host(self, imap_host):
        """Sets the imap_host of this ProviderSettings.


        :param imap_host: The imap_host of this ProviderSettings.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and imap_host is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_host`, must not be `None`")  # noqa: E501

        self._imap_host = imap_host

    @property
    def imap_port(self):
        """Gets the imap_port of this ProviderSettings.  # noqa: E501


        :return: The imap_port of this ProviderSettings.  # noqa: E501
        :rtype: int
        """
        return self._imap_port

    @imap_port.setter
    def imap_port(self, imap_port):
        """Sets the imap_port of this ProviderSettings.


        :param imap_port: The imap_port of this ProviderSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and imap_port is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_port`, must not be `None`")  # noqa: E501

        self._imap_port = imap_port

    @property
    def imap_ssl(self):
        """Gets the imap_ssl of this ProviderSettings.  # noqa: E501


        :return: The imap_ssl of this ProviderSettings.  # noqa: E501
        :rtype: bool
        """
        return self._imap_ssl

    @imap_ssl.setter
    def imap_ssl(self, imap_ssl):
        """Sets the imap_ssl of this ProviderSettings.


        :param imap_ssl: The imap_ssl of this ProviderSettings.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and imap_ssl is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_ssl`, must not be `None`")  # noqa: E501

        self._imap_ssl = imap_ssl

    @property
    def imap_start_tls(self):
        """Gets the imap_start_tls of this ProviderSettings.  # noqa: E501


        :return: The imap_start_tls of this ProviderSettings.  # noqa: E501
        :rtype: bool
        """
        return self._imap_start_tls

    @imap_start_tls.setter
    def imap_start_tls(self, imap_start_tls):
        """Sets the imap_start_tls of this ProviderSettings.


        :param imap_start_tls: The imap_start_tls of this ProviderSettings.  # noqa: E501
        :type: bool
        """

        self._imap_start_tls = imap_start_tls

    @property
    def smtp_host(self):
        """Gets the smtp_host of this ProviderSettings.  # noqa: E501


        :return: The smtp_host of this ProviderSettings.  # noqa: E501
        :rtype: str
        """
        return self._smtp_host

    @smtp_host.setter
    def smtp_host(self, smtp_host):
        """Sets the smtp_host of this ProviderSettings.


        :param smtp_host: The smtp_host of this ProviderSettings.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and smtp_host is None:  # noqa: E501
            raise ValueError("Invalid value for `smtp_host`, must not be `None`")  # noqa: E501

        self._smtp_host = smtp_host

    @property
    def smtp_port(self):
        """Gets the smtp_port of this ProviderSettings.  # noqa: E501


        :return: The smtp_port of this ProviderSettings.  # noqa: E501
        :rtype: int
        """
        return self._smtp_port

    @smtp_port.setter
    def smtp_port(self, smtp_port):
        """Sets the smtp_port of this ProviderSettings.


        :param smtp_port: The smtp_port of this ProviderSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and smtp_port is None:  # noqa: E501
            raise ValueError("Invalid value for `smtp_port`, must not be `None`")  # noqa: E501

        self._smtp_port = smtp_port

    @property
    def smtp_ssl(self):
        """Gets the smtp_ssl of this ProviderSettings.  # noqa: E501


        :return: The smtp_ssl of this ProviderSettings.  # noqa: E501
        :rtype: bool
        """
        return self._smtp_ssl

    @smtp_ssl.setter
    def smtp_ssl(self, smtp_ssl):
        """Sets the smtp_ssl of this ProviderSettings.


        :param smtp_ssl: The smtp_ssl of this ProviderSettings.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and smtp_ssl is None:  # noqa: E501
            raise ValueError("Invalid value for `smtp_ssl`, must not be `None`")  # noqa: E501

        self._smtp_ssl = smtp_ssl

    @property
    def smtp_start_tls(self):
        """Gets the smtp_start_tls of this ProviderSettings.  # noqa: E501


        :return: The smtp_start_tls of this ProviderSettings.  # noqa: E501
        :rtype: bool
        """
        return self._smtp_start_tls

    @smtp_start_tls.setter
    def smtp_start_tls(self, smtp_start_tls):
        """Sets the smtp_start_tls of this ProviderSettings.


        :param smtp_start_tls: The smtp_start_tls of this ProviderSettings.  # noqa: E501
        :type: bool
        """

        self._smtp_start_tls = smtp_start_tls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProviderSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProviderSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class OptInConsentOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'email_address': 'str',
        'company_name': 'str',
        'send_opt_in_options': 'SendOptInConsentEmailOptions'
    }

    attribute_map = {
        'email_address': 'emailAddress',
        'company_name': 'companyName',
        'send_opt_in_options': 'sendOptInOptions'
    }

    def __init__(self, email_address=None, company_name=None, send_opt_in_options=None, local_vars_configuration=None):  # noqa: E501
        """OptInConsentOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._email_address = None
        self._company_name = None
        self._send_opt_in_options = None
        self.discriminator = None

        self.email_address = email_address
        if company_name is not None:
            self.company_name = company_name
        if send_opt_in_options is not None:
            self.send_opt_in_options = send_opt_in_options

    @property
    def email_address(self):
        """Gets the email_address of this OptInConsentOptions.  # noqa: E501


        :return: The email_address of this OptInConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this OptInConsentOptions.


        :param email_address: The email_address of this OptInConsentOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and email_address is None:  # noqa: E501
            raise ValueError("Invalid value for `email_address`, must not be `None`")  # noqa: E501

        self._email_address = email_address

    @property
    def company_name(self):
        """Gets the company_name of this OptInConsentOptions.  # noqa: E501


        :return: The company_name of this OptInConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this OptInConsentOptions.


        :param company_name: The company_name of this OptInConsentOptions.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def send_opt_in_options(self):
        """Gets the send_opt_in_options of this OptInConsentOptions.  # noqa: E501


        :return: The send_opt_in_options of this OptInConsentOptions.  # noqa: E501
        :rtype: SendOptInConsentEmailOptions
        """
        return self._send_opt_in_options

    @send_opt_in_options.setter
    def send_opt_in_options(self, send_opt_in_options):
        """Sets the send_opt_in_options of this OptInConsentOptions.


        :param send_opt_in_options: The send_opt_in_options of this OptInConsentOptions.  # noqa: E501
        :type: SendOptInConsentEmailOptions
        """

        self._send_opt_in_options = send_opt_in_options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptInConsentOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OptInConsentOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailFeatureOverview(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'feature': 'str',
        'title': 'str',
        'description': 'str',
        'category': 'str',
        'notes': 'str',
        'notes_numbers': 'dict(str, str)',
        'feature_statistics': 'list[EmailFeatureFamilyStatistics]',
        'statuses': 'list[str]'
    }

    attribute_map = {
        'feature': 'feature',
        'title': 'title',
        'description': 'description',
        'category': 'category',
        'notes': 'notes',
        'notes_numbers': 'notesNumbers',
        'feature_statistics': 'featureStatistics',
        'statuses': 'statuses'
    }

    def __init__(self, feature=None, title=None, description=None, category=None, notes=None, notes_numbers=None, feature_statistics=None, statuses=None, local_vars_configuration=None):  # noqa: E501
        """EmailFeatureOverview - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._feature = None
        self._title = None
        self._description = None
        self._category = None
        self._notes = None
        self._notes_numbers = None
        self._feature_statistics = None
        self._statuses = None
        self.discriminator = None

        self.feature = feature
        if title is not None:
            self.title = title
        if description is not None:
            self.description = description
        if category is not None:
            self.category = category
        if notes is not None:
            self.notes = notes
        if notes_numbers is not None:
            self.notes_numbers = notes_numbers
        if feature_statistics is not None:
            self.feature_statistics = feature_statistics
        self.statuses = statuses

    @property
    def feature(self):
        """Gets the feature of this EmailFeatureOverview.  # noqa: E501


        :return: The feature of this EmailFeatureOverview.  # noqa: E501
        :rtype: str
        """
        return self._feature

    @feature.setter
    def feature(self, feature):
        """Sets the feature of this EmailFeatureOverview.


        :param feature: The feature of this EmailFeatureOverview.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and feature is None:  # noqa: E501
            raise ValueError("Invalid value for `feature`, must not be `None`")  # noqa: E501
        allowed_values = ["amp", "css-accent-color", "css-align-items", "css-animation", "css-aspect-ratio", "css-at-font-face", "css-at-import", "css-at-keyframes", "css-at-media", "css-at-supports", "css-background-blend-mode", "css-background-clip", "css-background-color", "css-background-image", "css-background-origin", "css-background-position", "css-background-repeat", "css-background-size", "css-background", "css-block-inline-size", "css-border-image", "css-border-inline-block-individual", "css-border-inline-block-longhand", "css-border-inline-block", "css-border-radius-logical", "css-border-radius", "css-border", "css-box-shadow", "css-box-sizing", "css-caption-side", "css-clip-path", "css-column-count", "css-column-layout-properties", "css-direction", "css-display-flex", "css-display-grid", "css-display-none", "css-display", "css-filter", "css-flex-direction", "css-flex-wrap", "css-float", "css-font-kerning", "css-font-weight", "css-font", "css-gap", "css-grid-template", "css-height", "css-hyphens", "css-inline-size", "css-justify-content", "css-left-right-top-bottom", "css-letter-spacing", "css-line-height", "css-list-style-image", "css-list-style-position", "css-list-style-type", "css-list-style", "css-margin-block-start-end", "css-margin-inline-block", "css-margin-inline-start-end", "css-margin-inline", "css-margin", "css-max-block-size", "css-max-height", "css-max-width", "css-min-height", "css-min-inline-size", "css-min-width", "css-mix-blend-mode", "css-object-fit", "css-object-position", "css-opacity", "css-outline-offset", "css-outline", "css-overflow-wrap", "css-overflow", "css-padding-block-start-end", "css-padding-inline-block", "css-padding-inline-start-end", "css-padding", "css-position", "css-tab-size", "css-table-layout", "css-text-align-last", "css-text-align", "css-text-decoration-color", "css-text-decoration-thickness", "css-text-decoration", "css-text-emphasis-position", "css-text-emphasis", "css-text-indent", "css-text-overflow", "css-text-shadow", "css-text-transform", "css-text-underline-offset", "css-transform", "css-vertical-align", "css-visibility", "css-white-space", "css-width", "css-word-break", "css-writing-mode", "css-z-index", "html-abbr", "html-address", "html-align", "html-anchor-links", "html-aria-describedby", "html-aria-hidden", "html-aria-label", "html-aria-labelledby", "html-aria-live", "html-audio", "html-background", "html-base", "html-blockquote", "html-body", "html-button-reset", "html-button-submit", "html-code", "html-del", "html-dfn", "html-dialog", "html-dir", "html-div", "html-doctype", "html-form", "html-h1-h6", "html-height", "html-image-maps", "html-input-checkbox", "html-input-hidden", "html-input-radio", "html-input-reset", "html-input-submit", "html-input-text", "html-lang", "html-link", "html-lists", "html-loading-attribute", "html-mailto-links", "html-marquee", "html-meter", "html-object", "html-p", "html-picture", "html-pre", "html-progress", "html-required", "html-role", "html-rp", "html-rt", "html-ruby", "html-select", "html-semantics", "html-small", "html-span", "html-srcset", "html-strike", "html-strong", "html-style", "html-svg", "html-table", "html-target", "html-textarea", "html-valign", "html-video", "html-wbr", "html-width", "image-avif", "image-base64", "image-bmp", "image-gif", "image-ico", "image-jpg", "image-png", "image-svg", "image-webp", "unsupported"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and feature not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `feature` ({0}), must be one of {1}"  # noqa: E501
                .format(feature, allowed_values)
            )

        self._feature = feature

    @property
    def title(self):
        """Gets the title of this EmailFeatureOverview.  # noqa: E501


        :return: The title of this EmailFeatureOverview.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this EmailFeatureOverview.


        :param title: The title of this EmailFeatureOverview.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def description(self):
        """Gets the description of this EmailFeatureOverview.  # noqa: E501


        :return: The description of this EmailFeatureOverview.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this EmailFeatureOverview.


        :param description: The description of this EmailFeatureOverview.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def category(self):
        """Gets the category of this EmailFeatureOverview.  # noqa: E501


        :return: The category of this EmailFeatureOverview.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this EmailFeatureOverview.


        :param category: The category of this EmailFeatureOverview.  # noqa: E501
        :type: str
        """
        allowed_values = ["css", "html", "image", "others"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and category not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    @property
    def notes(self):
        """Gets the notes of this EmailFeatureOverview.  # noqa: E501


        :return: The notes of this EmailFeatureOverview.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this EmailFeatureOverview.


        :param notes: The notes of this EmailFeatureOverview.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def notes_numbers(self):
        """Gets the notes_numbers of this EmailFeatureOverview.  # noqa: E501


        :return: The notes_numbers of this EmailFeatureOverview.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._notes_numbers

    @notes_numbers.setter
    def notes_numbers(self, notes_numbers):
        """Sets the notes_numbers of this EmailFeatureOverview.


        :param notes_numbers: The notes_numbers of this EmailFeatureOverview.  # noqa: E501
        :type: dict(str, str)
        """

        self._notes_numbers = notes_numbers

    @property
    def feature_statistics(self):
        """Gets the feature_statistics of this EmailFeatureOverview.  # noqa: E501


        :return: The feature_statistics of this EmailFeatureOverview.  # noqa: E501
        :rtype: list[EmailFeatureFamilyStatistics]
        """
        return self._feature_statistics

    @feature_statistics.setter
    def feature_statistics(self, feature_statistics):
        """Sets the feature_statistics of this EmailFeatureOverview.


        :param feature_statistics: The feature_statistics of this EmailFeatureOverview.  # noqa: E501
        :type: list[EmailFeatureFamilyStatistics]
        """

        self._feature_statistics = feature_statistics

    @property
    def statuses(self):
        """Gets the statuses of this EmailFeatureOverview.  # noqa: E501


        :return: The statuses of this EmailFeatureOverview.  # noqa: E501
        :rtype: list[str]
        """
        return self._statuses

    @statuses.setter
    def statuses(self, statuses):
        """Sets the statuses of this EmailFeatureOverview.


        :param statuses: The statuses of this EmailFeatureOverview.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and statuses is None:  # noqa: E501
            raise ValueError("Invalid value for `statuses`, must not be `None`")  # noqa: E501
        allowed_values = ["SUPPORTED", "PARTIAL", "NOT_SUPPORTED", "UNKNOWN"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(statuses).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `statuses` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(statuses) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._statuses = statuses

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailFeatureOverview):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailFeatureOverview):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ScheduledJob(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'inbox_id': 'str',
        'job_id': 'str',
        'group_id': 'str',
        'trigger_id': 'str',
        'status': 'str',
        'send_at_timestamp': 'datetime',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'inbox_id': 'inboxId',
        'job_id': 'jobId',
        'group_id': 'groupId',
        'trigger_id': 'triggerId',
        'status': 'status',
        'send_at_timestamp': 'sendAtTimestamp',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, user_id=None, inbox_id=None, job_id=None, group_id=None, trigger_id=None, status=None, send_at_timestamp=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """ScheduledJob - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._inbox_id = None
        self._job_id = None
        self._group_id = None
        self._trigger_id = None
        self._status = None
        self._send_at_timestamp = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.inbox_id = inbox_id
        self.job_id = job_id
        self.group_id = group_id
        self.trigger_id = trigger_id
        self.status = status
        self.send_at_timestamp = send_at_timestamp
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this ScheduledJob.  # noqa: E501


        :return: The id of this ScheduledJob.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ScheduledJob.


        :param id: The id of this ScheduledJob.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this ScheduledJob.  # noqa: E501


        :return: The user_id of this ScheduledJob.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ScheduledJob.


        :param user_id: The user_id of this ScheduledJob.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this ScheduledJob.  # noqa: E501


        :return: The inbox_id of this ScheduledJob.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this ScheduledJob.


        :param inbox_id: The inbox_id of this ScheduledJob.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and inbox_id is None:  # noqa: E501
            raise ValueError("Invalid value for `inbox_id`, must not be `None`")  # noqa: E501

        self._inbox_id = inbox_id

    @property
    def job_id(self):
        """Gets the job_id of this ScheduledJob.  # noqa: E501


        :return: The job_id of this ScheduledJob.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this ScheduledJob.


        :param job_id: The job_id of this ScheduledJob.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and job_id is None:  # noqa: E501
            raise ValueError("Invalid value for `job_id`, must not be `None`")  # noqa: E501

        self._job_id = job_id

    @property
    def group_id(self):
        """Gets the group_id of this ScheduledJob.  # noqa: E501


        :return: The group_id of this ScheduledJob.  # noqa: E501
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this ScheduledJob.


        :param group_id: The group_id of this ScheduledJob.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and group_id is None:  # noqa: E501
            raise ValueError("Invalid value for `group_id`, must not be `None`")  # noqa: E501

        self._group_id = group_id

    @property
    def trigger_id(self):
        """Gets the trigger_id of this ScheduledJob.  # noqa: E501


        :return: The trigger_id of this ScheduledJob.  # noqa: E501
        :rtype: str
        """
        return self._trigger_id

    @trigger_id.setter
    def trigger_id(self, trigger_id):
        """Sets the trigger_id of this ScheduledJob.


        :param trigger_id: The trigger_id of this ScheduledJob.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and trigger_id is None:  # noqa: E501
            raise ValueError("Invalid value for `trigger_id`, must not be `None`")  # noqa: E501

        self._trigger_id = trigger_id

    @property
    def status(self):
        """Gets the status of this ScheduledJob.  # noqa: E501


        :return: The status of this ScheduledJob.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ScheduledJob.


        :param status: The status of this ScheduledJob.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["SUBMITTED", "COMPLETED", "ABORTED", "FAILED", "CANCELLED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def send_at_timestamp(self):
        """Gets the send_at_timestamp of this ScheduledJob.  # noqa: E501


        :return: The send_at_timestamp of this ScheduledJob.  # noqa: E501
        :rtype: datetime
        """
        return self._send_at_timestamp

    @send_at_timestamp.setter
    def send_at_timestamp(self, send_at_timestamp):
        """Sets the send_at_timestamp of this ScheduledJob.


        :param send_at_timestamp: The send_at_timestamp of this ScheduledJob.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and send_at_timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `send_at_timestamp`, must not be `None`")  # noqa: E501

        self._send_at_timestamp = send_at_timestamp

    @property
    def created_at(self):
        """Gets the created_at of this ScheduledJob.  # noqa: E501


        :return: The created_at of this ScheduledJob.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ScheduledJob.


        :param created_at: The created_at of this ScheduledJob.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this ScheduledJob.  # noqa: E501


        :return: The updated_at of this ScheduledJob.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ScheduledJob.


        :param updated_at: The updated_at of this ScheduledJob.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScheduledJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScheduledJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailFeatureFamilyStatistics(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'feature': 'str',
        'family': 'str',
        'platforms': 'list[EmailFeaturePlatformStatistics]'
    }

    attribute_map = {
        'feature': 'feature',
        'family': 'family',
        'platforms': 'platforms'
    }

    def __init__(self, feature=None, family=None, platforms=None, local_vars_configuration=None):  # noqa: E501
        """EmailFeatureFamilyStatistics - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._feature = None
        self._family = None
        self._platforms = None
        self.discriminator = None

        self.feature = feature
        self.family = family
        self.platforms = platforms

    @property
    def feature(self):
        """Gets the feature of this EmailFeatureFamilyStatistics.  # noqa: E501


        :return: The feature of this EmailFeatureFamilyStatistics.  # noqa: E501
        :rtype: str
        """
        return self._feature

    @feature.setter
    def feature(self, feature):
        """Sets the feature of this EmailFeatureFamilyStatistics.


        :param feature: The feature of this EmailFeatureFamilyStatistics.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and feature is None:  # noqa: E501
            raise ValueError("Invalid value for `feature`, must not be `None`")  # noqa: E501
        allowed_values = ["amp", "css-accent-color", "css-align-items", "css-animation", "css-aspect-ratio", "css-at-font-face", "css-at-import", "css-at-keyframes", "css-at-media", "css-at-supports", "css-background-blend-mode", "css-background-clip", "css-background-color", "css-background-image", "css-background-origin", "css-background-position", "css-background-repeat", "css-background-size", "css-background", "css-block-inline-size", "css-border-image", "css-border-inline-block-individual", "css-border-inline-block-longhand", "css-border-inline-block", "css-border-radius-logical", "css-border-radius", "css-border", "css-box-shadow", "css-box-sizing", "css-caption-side", "css-clip-path", "css-column-count", "css-column-layout-properties", "css-direction", "css-display-flex", "css-display-grid", "css-display-none", "css-display", "css-filter", "css-flex-direction", "css-flex-wrap", "css-float", "css-font-kerning", "css-font-weight", "css-font", "css-gap", "css-grid-template", "css-height", "css-hyphens", "css-inline-size", "css-justify-content", "css-left-right-top-bottom", "css-letter-spacing", "css-line-height", "css-list-style-image", "css-list-style-position", "css-list-style-type", "css-list-style", "css-margin-block-start-end", "css-margin-inline-block", "css-margin-inline-start-end", "css-margin-inline", "css-margin", "css-max-block-size", "css-max-height", "css-max-width", "css-min-height", "css-min-inline-size", "css-min-width", "css-mix-blend-mode", "css-object-fit", "css-object-position", "css-opacity", "css-outline-offset", "css-outline", "css-overflow-wrap", "css-overflow", "css-padding-block-start-end", "css-padding-inline-block", "css-padding-inline-start-end", "css-padding", "css-position", "css-tab-size", "css-table-layout", "css-text-align-last", "css-text-align", "css-text-decoration-color", "css-text-decoration-thickness", "css-text-decoration", "css-text-emphasis-position", "css-text-emphasis", "css-text-indent", "css-text-overflow", "css-text-shadow", "css-text-transform", "css-text-underline-offset", "css-transform", "css-vertical-align", "css-visibility", "css-white-space", "css-width", "css-word-break", "css-writing-mode", "css-z-index", "html-abbr", "html-address", "html-align", "html-anchor-links", "html-aria-describedby", "html-aria-hidden", "html-aria-label", "html-aria-labelledby", "html-aria-live", "html-audio", "html-background", "html-base", "html-blockquote", "html-body", "html-button-reset", "html-button-submit", "html-code", "html-del", "html-dfn", "html-dialog", "html-dir", "html-div", "html-doctype", "html-form", "html-h1-h6", "html-height", "html-image-maps", "html-input-checkbox", "html-input-hidden", "html-input-radio", "html-input-reset", "html-input-submit", "html-input-text", "html-lang", "html-link", "html-lists", "html-loading-attribute", "html-mailto-links", "html-marquee", "html-meter", "html-object", "html-p", "html-picture", "html-pre", "html-progress", "html-required", "html-role", "html-rp", "html-rt", "html-ruby", "html-select", "html-semantics", "html-small", "html-span", "html-srcset", "html-strike", "html-strong", "html-style", "html-svg", "html-table", "html-target", "html-textarea", "html-valign", "html-video", "html-wbr", "html-width", "image-avif", "image-base64", "image-bmp", "image-gif", "image-ico", "image-jpg", "image-png", "image-svg", "image-webp", "unsupported"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and feature not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `feature` ({0}), must be one of {1}"  # noqa: E501
                .format(feature, allowed_values)
            )

        self._feature = feature

    @property
    def family(self):
        """Gets the family of this EmailFeatureFamilyStatistics.  # noqa: E501


        :return: The family of this EmailFeatureFamilyStatistics.  # noqa: E501
        :rtype: str
        """
        return self._family

    @family.setter
    def family(self, family):
        """Sets the family of this EmailFeatureFamilyStatistics.


        :param family: The family of this EmailFeatureFamilyStatistics.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and family is None:  # noqa: E501
            raise ValueError("Invalid value for `family`, must not be `None`")  # noqa: E501
        allowed_values = ["aol", "apple-mail", "fastmail", "free-fr", "gmail", "gmx", "hey", "ionos-1and1", "laposte", "mail-ru", "microsoft", "orange", "outlook", "protonmail", "rainloop", "samsung-email", "sfr", "t-online-de", "thunderbird", "web-de", "yahoo"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and family not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `family` ({0}), must be one of {1}"  # noqa: E501
                .format(family, allowed_values)
            )

        self._family = family

    @property
    def platforms(self):
        """Gets the platforms of this EmailFeatureFamilyStatistics.  # noqa: E501


        :return: The platforms of this EmailFeatureFamilyStatistics.  # noqa: E501
        :rtype: list[EmailFeaturePlatformStatistics]
        """
        return self._platforms

    @platforms.setter
    def platforms(self, platforms):
        """Sets the platforms of this EmailFeatureFamilyStatistics.


        :param platforms: The platforms of this EmailFeatureFamilyStatistics.  # noqa: E501
        :type: list[EmailFeaturePlatformStatistics]
        """
        if self.local_vars_configuration.client_side_validation and platforms is None:  # noqa: E501
            raise ValueError("Invalid value for `platforms`, must not be `None`")  # noqa: E501

        self._platforms = platforms

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailFeatureFamilyStatistics):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailFeatureFamilyStatistics):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneNumberDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'user_id': 'str',
        'compliance_address': 'str',
        'emergency_address': 'str',
        'phone_number': 'str',
        'phone_country': 'str',
        'phone_plan': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'favourite': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'user_id': 'userId',
        'compliance_address': 'complianceAddress',
        'emergency_address': 'emergencyAddress',
        'phone_number': 'phoneNumber',
        'phone_country': 'phoneCountry',
        'phone_plan': 'phonePlan',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'favourite': 'favourite'
    }

    def __init__(self, id=None, name=None, description=None, user_id=None, compliance_address=None, emergency_address=None, phone_number=None, phone_country=None, phone_plan=None, created_at=None, updated_at=None, favourite=None, local_vars_configuration=None):  # noqa: E501
        """PhoneNumberDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._user_id = None
        self._compliance_address = None
        self._emergency_address = None
        self._phone_number = None
        self._phone_country = None
        self._phone_plan = None
        self._created_at = None
        self._updated_at = None
        self._favourite = None
        self.discriminator = None

        self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        self.user_id = user_id
        if compliance_address is not None:
            self.compliance_address = compliance_address
        if emergency_address is not None:
            self.emergency_address = emergency_address
        self.phone_number = phone_number
        self.phone_country = phone_country
        self.phone_plan = phone_plan
        self.created_at = created_at
        self.updated_at = updated_at
        self.favourite = favourite

    @property
    def id(self):
        """Gets the id of this PhoneNumberDto.  # noqa: E501


        :return: The id of this PhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhoneNumberDto.


        :param id: The id of this PhoneNumberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this PhoneNumberDto.  # noqa: E501


        :return: The name of this PhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PhoneNumberDto.


        :param name: The name of this PhoneNumberDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this PhoneNumberDto.  # noqa: E501


        :return: The description of this PhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PhoneNumberDto.


        :param description: The description of this PhoneNumberDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def user_id(self):
        """Gets the user_id of this PhoneNumberDto.  # noqa: E501


        :return: The user_id of this PhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PhoneNumberDto.


        :param user_id: The user_id of this PhoneNumberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def compliance_address(self):
        """Gets the compliance_address of this PhoneNumberDto.  # noqa: E501


        :return: The compliance_address of this PhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._compliance_address

    @compliance_address.setter
    def compliance_address(self, compliance_address):
        """Sets the compliance_address of this PhoneNumberDto.


        :param compliance_address: The compliance_address of this PhoneNumberDto.  # noqa: E501
        :type: str
        """

        self._compliance_address = compliance_address

    @property
    def emergency_address(self):
        """Gets the emergency_address of this PhoneNumberDto.  # noqa: E501


        :return: The emergency_address of this PhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._emergency_address

    @emergency_address.setter
    def emergency_address(self, emergency_address):
        """Sets the emergency_address of this PhoneNumberDto.


        :param emergency_address: The emergency_address of this PhoneNumberDto.  # noqa: E501
        :type: str
        """

        self._emergency_address = emergency_address

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneNumberDto.  # noqa: E501


        :return: The phone_number of this PhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneNumberDto.


        :param phone_number: The phone_number of this PhoneNumberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def phone_country(self):
        """Gets the phone_country of this PhoneNumberDto.  # noqa: E501


        :return: The phone_country of this PhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhoneNumberDto.


        :param phone_country: The phone_country of this PhoneNumberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "CH", "PT", "NL", "IL", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_plan(self):
        """Gets the phone_plan of this PhoneNumberDto.  # noqa: E501


        :return: The phone_plan of this PhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_plan

    @phone_plan.setter
    def phone_plan(self, phone_plan):
        """Sets the phone_plan of this PhoneNumberDto.


        :param phone_plan: The phone_plan of this PhoneNumberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_plan is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_plan`, must not be `None`")  # noqa: E501

        self._phone_plan = phone_plan

    @property
    def created_at(self):
        """Gets the created_at of this PhoneNumberDto.  # noqa: E501


        :return: The created_at of this PhoneNumberDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhoneNumberDto.


        :param created_at: The created_at of this PhoneNumberDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this PhoneNumberDto.  # noqa: E501


        :return: The updated_at of this PhoneNumberDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PhoneNumberDto.


        :param updated_at: The updated_at of this PhoneNumberDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def favourite(self):
        """Gets the favourite of this PhoneNumberDto.  # noqa: E501


        :return: The favourite of this PhoneNumberDto.  # noqa: E501
        :rtype: bool
        """
        return self._favourite

    @favourite.setter
    def favourite(self, favourite):
        """Sets the favourite of this PhoneNumberDto.


        :param favourite: The favourite of this PhoneNumberDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and favourite is None:  # noqa: E501
            raise ValueError("Invalid value for `favourite`, must not be `None`")  # noqa: E501

        self._favourite = favourite

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneNumberDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneNumberDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneNumberProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'created_at': 'datetime',
        'phone_number': 'str',
        'phone_country': 'str',
        'name': 'str',
        'id': 'str'
    }

    attribute_map = {
        'user_id': 'userId',
        'created_at': 'createdAt',
        'phone_number': 'phoneNumber',
        'phone_country': 'phoneCountry',
        'name': 'name',
        'id': 'id'
    }

    def __init__(self, user_id=None, created_at=None, phone_number=None, phone_country=None, name=None, id=None, local_vars_configuration=None):  # noqa: E501
        """PhoneNumberProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._created_at = None
        self._phone_number = None
        self._phone_country = None
        self._name = None
        self._id = None
        self.discriminator = None

        self.user_id = user_id
        self.created_at = created_at
        self.phone_number = phone_number
        self.phone_country = phone_country
        if name is not None:
            self.name = name
        self.id = id

    @property
    def user_id(self):
        """Gets the user_id of this PhoneNumberProjection.  # noqa: E501


        :return: The user_id of this PhoneNumberProjection.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PhoneNumberProjection.


        :param user_id: The user_id of this PhoneNumberProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def created_at(self):
        """Gets the created_at of this PhoneNumberProjection.  # noqa: E501


        :return: The created_at of this PhoneNumberProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhoneNumberProjection.


        :param created_at: The created_at of this PhoneNumberProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneNumberProjection.  # noqa: E501


        :return: The phone_number of this PhoneNumberProjection.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneNumberProjection.


        :param phone_number: The phone_number of this PhoneNumberProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def phone_country(self):
        """Gets the phone_country of this PhoneNumberProjection.  # noqa: E501


        :return: The phone_country of this PhoneNumberProjection.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhoneNumberProjection.


        :param phone_country: The phone_country of this PhoneNumberProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "CH", "PT", "NL", "IL", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def name(self):
        """Gets the name of this PhoneNumberProjection.  # noqa: E501


        :return: The name of this PhoneNumberProjection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PhoneNumberProjection.


        :param name: The name of this PhoneNumberProjection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this PhoneNumberProjection.  # noqa: E501


        :return: The id of this PhoneNumberProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhoneNumberProjection.


        :param id: The id of this PhoneNumberProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneNumberProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneNumberProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EntityAutomationItemProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'inbox_id': 'str',
        'phone_id': 'str',
        'action': 'str',
        'automation_type': 'str',
        'name': 'str',
        'id': 'str'
    }

    attribute_map = {
        'inbox_id': 'inboxId',
        'phone_id': 'phoneId',
        'action': 'action',
        'automation_type': 'automationType',
        'name': 'name',
        'id': 'id'
    }

    def __init__(self, inbox_id=None, phone_id=None, action=None, automation_type=None, name=None, id=None, local_vars_configuration=None):  # noqa: E501
        """EntityAutomationItemProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._inbox_id = None
        self._phone_id = None
        self._action = None
        self._automation_type = None
        self._name = None
        self._id = None
        self.discriminator = None

        if inbox_id is not None:
            self.inbox_id = inbox_id
        if phone_id is not None:
            self.phone_id = phone_id
        if action is not None:
            self.action = action
        self.automation_type = automation_type
        if name is not None:
            self.name = name
        self.id = id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this EntityAutomationItemProjection.  # noqa: E501


        :return: The inbox_id of this EntityAutomationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this EntityAutomationItemProjection.


        :param inbox_id: The inbox_id of this EntityAutomationItemProjection.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def phone_id(self):
        """Gets the phone_id of this EntityAutomationItemProjection.  # noqa: E501


        :return: The phone_id of this EntityAutomationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._phone_id

    @phone_id.setter
    def phone_id(self, phone_id):
        """Sets the phone_id of this EntityAutomationItemProjection.


        :param phone_id: The phone_id of this EntityAutomationItemProjection.  # noqa: E501
        :type: str
        """

        self._phone_id = phone_id

    @property
    def action(self):
        """Gets the action of this EntityAutomationItemProjection.  # noqa: E501


        :return: The action of this EntityAutomationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this EntityAutomationItemProjection.


        :param action: The action of this EntityAutomationItemProjection.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def automation_type(self):
        """Gets the automation_type of this EntityAutomationItemProjection.  # noqa: E501


        :return: The automation_type of this EntityAutomationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._automation_type

    @automation_type.setter
    def automation_type(self, automation_type):
        """Sets the automation_type of this EntityAutomationItemProjection.


        :param automation_type: The automation_type of this EntityAutomationItemProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and automation_type is None:  # noqa: E501
            raise ValueError("Invalid value for `automation_type`, must not be `None`")  # noqa: E501
        allowed_values = ["INBOX_FORWARDER", "INBOX_REPLIER", "INBOX_RULESET"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and automation_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `automation_type` ({0}), must be one of {1}"  # noqa: E501
                .format(automation_type, allowed_values)
            )

        self._automation_type = automation_type

    @property
    def name(self):
        """Gets the name of this EntityAutomationItemProjection.  # noqa: E501


        :return: The name of this EntityAutomationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EntityAutomationItemProjection.


        :param name: The name of this EntityAutomationItemProjection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this EntityAutomationItemProjection.  # noqa: E501


        :return: The id of this EntityAutomationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EntityAutomationItemProjection.


        :param id: The id of this EntityAutomationItemProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EntityAutomationItemProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EntityAutomationItemProjection):
            return True

        return self.to_dict() != other.to_dict()
